"use strict";

const ee = require("./eventemitter");

const panelClass = "c-primary-nav";
const eventNamespace = "tgam-primary-nav";

module.exports = {

  init: function(buttonRoot, panelRoot) {
    this.panel = panelRoot;
    this.button = buttonRoot.getElementsByClassName("c-primary-nav-button__button").item(0);
    this.buttonText = buttonRoot.getElementsByClassName("c-primary-nav-button__text").item(0);

    if (this.panel && this.button) {
      this.button.addEventListener("click", () => {
        this.toggle();
      });
      this.panel.addEventListener("animationend", () => {
        this.onPanelAnimationEnd();
      });
    }
  },

  isOpen: function() {
    return this.button.getAttribute("aria-expanded") === "true";
  },

  toggle: function(e) {
    if (this.isOpen()) {
      this.close();
    } else {
      this.open();
    }
  },

  open: function() {
    this.button.setAttribute("aria-expanded", true);
    this.buttonText.textContent = "Hide navigation";
    this.panel.classList.remove(`${panelClass}--hiding`);
    this.panel.classList.add(`${panelClass}--revealing`);
    this.panel.removeAttribute("hidden");
    ee.emitEvent(`${eventNamespace}:opening`);
  },

  close: function() {
    this.button.setAttribute("aria-expanded", false);
    this.buttonText.textContent = "Show navigation";
    this.panel.classList.remove(`${panelClass}--revealing`);
    this.panel.classList.add(`${panelClass}--hiding`);
    ee.emitEvent(`${eventNamespace}:closing`);
  },

  onPanelAnimationEnd: function(e) {
    // Using classList.remove() with multiple arguments fails in IE11,
    // so we're removing classes separately
    this.panel.classList.remove(`${panelClass}--hiding`);
    this.panel.classList.remove(`${panelClass}--revealing`);
    if (this.button.getAttribute("aria-expanded") === "false") {
      this.panel.setAttribute("hidden", "hidden");
      ee.emitEvent(`${eventNamespace}:closed`);
    } else {
      ee.emitEvent(`${eventNamespace}:open`);
    }
  }

};
